# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: redhat.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='redhat.proto',
  package='strobesbufs.scrappers.redhat',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0credhat.proto\x12\x1cstrobesbufs.scrappers.redhat\"\x97\x02\n\x06Redhat\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0b\n\x03\x63ve\x18\x02 \x01(\t\x12\x10\n\x08severity\x18\x03 \x01(\x05\x12\x16\n\x0epublished_date\x18\x04 \x01(\t\x12\x12\n\nadvisories\x18\x05 \x03(\t\x12\x10\n\x08\x62ugzilla\x18\x06 \x01(\t\x12\x1c\n\x14\x62ugzilla_description\x18\x07 \x01(\t\x12\x0c\n\x04\x63vss\x18\x08 \x01(\x02\x12\x13\n\x0b\x63vss_vector\x18\t \x01(\t\x12\x0b\n\x03\x63we\x18\n \x01(\t\x12\x19\n\x11\x61\x66\x66\x65\x63ted_packages\x18\x0b \x03(\t\x12\x12\n\nreferences\x18\x0c \x03(\t\x12\r\n\x05\x63vss3\x18\r \x01(\t\x12\x14\n\x0c\x63vss3_vector\x18\x0e \x01(\t\"B\n\nRedhatList\x12\x34\n\x06redhat\x18\x01 \x03(\x0b\x32$.strobesbufs.scrappers.redhat.Redhatb\x06proto3'
)




_REDHAT = _descriptor.Descriptor(
  name='Redhat',
  full_name='strobesbufs.scrappers.redhat.Redhat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='strobesbufs.scrappers.redhat.Redhat.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cve', full_name='strobesbufs.scrappers.redhat.Redhat.cve', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity', full_name='strobesbufs.scrappers.redhat.Redhat.severity', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published_date', full_name='strobesbufs.scrappers.redhat.Redhat.published_date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advisories', full_name='strobesbufs.scrappers.redhat.Redhat.advisories', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bugzilla', full_name='strobesbufs.scrappers.redhat.Redhat.bugzilla', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bugzilla_description', full_name='strobesbufs.scrappers.redhat.Redhat.bugzilla_description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss', full_name='strobesbufs.scrappers.redhat.Redhat.cvss', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss_vector', full_name='strobesbufs.scrappers.redhat.Redhat.cvss_vector', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cwe', full_name='strobesbufs.scrappers.redhat.Redhat.cwe', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affected_packages', full_name='strobesbufs.scrappers.redhat.Redhat.affected_packages', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='references', full_name='strobesbufs.scrappers.redhat.Redhat.references', index=11,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss3', full_name='strobesbufs.scrappers.redhat.Redhat.cvss3', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss3_vector', full_name='strobesbufs.scrappers.redhat.Redhat.cvss3_vector', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=326,
)


_REDHATLIST = _descriptor.Descriptor(
  name='RedhatList',
  full_name='strobesbufs.scrappers.redhat.RedhatList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='redhat', full_name='strobesbufs.scrappers.redhat.RedhatList.redhat', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=394,
)

_REDHATLIST.fields_by_name['redhat'].message_type = _REDHAT
DESCRIPTOR.message_types_by_name['Redhat'] = _REDHAT
DESCRIPTOR.message_types_by_name['RedhatList'] = _REDHATLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Redhat = _reflection.GeneratedProtocolMessageType('Redhat', (_message.Message,), {
  'DESCRIPTOR' : _REDHAT,
  '__module__' : 'redhat_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.redhat.Redhat)
  })
_sym_db.RegisterMessage(Redhat)

RedhatList = _reflection.GeneratedProtocolMessageType('RedhatList', (_message.Message,), {
  'DESCRIPTOR' : _REDHATLIST,
  '__module__' : 'redhat_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.redhat.RedhatList)
  })
_sym_db.RegisterMessage(RedhatList)


# @@protoc_insertion_point(module_scope)
