# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/messier/workflows/services.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from strobesbufs.messier.workflows import workflow_pb2 as strobesbufs_dot_messier_dot_workflows_dot_workflow__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/messier/workflows/services.proto',
  package='strobesbufs.messier.workflow.services',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,strobesbufs/messier/workflows/services.proto\x12%strobesbufs.messier.workflow.services\x1a\x1cgoogle/protobuf/struct.proto\x1a,strobesbufs/messier/workflows/workflow.proto\"\'\n\x17WorkflowValidateRequest\x12\x0c\n\x04yaml\x18\x01 \x01(\t\"\x8e\x01\n\x18WorkflowValidateResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\'\n\x06\x65rrors\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x38\n\x08workflow\x18\x03 \x01(\x0b\x32&.strobesbufs.messier.workflow.Workflow\"R\n\x16WorkflowExecuteRequest\x12\x38\n\x08workflow\x18\x01 \x01(\x0b\x32&.strobesbufs.messier.workflow.Workflow\"S\n\x17WorkflowExecuteResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\'\n\x06\x65rrors\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x90\x01\n\x11GetResultsRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12K\n\x04type\x18\x02 \x01(\x0e\x32=.strobesbufs.messier.workflow.services.GetResultsRequest.Type\"\"\n\x04Type\x12\x0c\n\x08WORKFLOW\x10\x00\x12\x0c\n\x08\x41NALYZER\x10\x01\">\n\x12GetResultsResponse\x12(\n\x07results\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\xc4\x03\n\x0fWorkflowService\x12\x95\x01\n\x10WorkflowValidate\x12>.strobesbufs.messier.workflow.services.WorkflowValidateRequest\x1a?.strobesbufs.messier.workflow.services.WorkflowValidateResponse\"\x00\x12\x92\x01\n\x0fWorkflowExecute\x12=.strobesbufs.messier.workflow.services.WorkflowExecuteRequest\x1a>.strobesbufs.messier.workflow.services.WorkflowExecuteResponse\"\x00\x12\x83\x01\n\nGetResults\x12\x38.strobesbufs.messier.workflow.services.GetResultsRequest\x1a\x39.strobesbufs.messier.workflow.services.GetResultsResponse\"\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_workflows_dot_workflow__pb2.DESCRIPTOR,])



_GETRESULTSREQUEST_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='strobesbufs.messier.workflow.services.GetResultsRequest.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANALYZER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=629,
  serialized_end=663,
)
_sym_db.RegisterEnumDescriptor(_GETRESULTSREQUEST_TYPE)


_WORKFLOWVALIDATEREQUEST = _descriptor.Descriptor(
  name='WorkflowValidateRequest',
  full_name='strobesbufs.messier.workflow.services.WorkflowValidateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='yaml', full_name='strobesbufs.messier.workflow.services.WorkflowValidateRequest.yaml', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=202,
)


_WORKFLOWVALIDATERESPONSE = _descriptor.Descriptor(
  name='WorkflowValidateResponse',
  full_name='strobesbufs.messier.workflow.services.WorkflowValidateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='strobesbufs.messier.workflow.services.WorkflowValidateResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='strobesbufs.messier.workflow.services.WorkflowValidateResponse.errors', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='strobesbufs.messier.workflow.services.WorkflowValidateResponse.workflow', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=347,
)


_WORKFLOWEXECUTEREQUEST = _descriptor.Descriptor(
  name='WorkflowExecuteRequest',
  full_name='strobesbufs.messier.workflow.services.WorkflowExecuteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='strobesbufs.messier.workflow.services.WorkflowExecuteRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=431,
)


_WORKFLOWEXECUTERESPONSE = _descriptor.Descriptor(
  name='WorkflowExecuteResponse',
  full_name='strobesbufs.messier.workflow.services.WorkflowExecuteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='strobesbufs.messier.workflow.services.WorkflowExecuteResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='strobesbufs.messier.workflow.services.WorkflowExecuteResponse.errors', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=433,
  serialized_end=516,
)


_GETRESULTSREQUEST = _descriptor.Descriptor(
  name='GetResultsRequest',
  full_name='strobesbufs.messier.workflow.services.GetResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.messier.workflow.services.GetResultsRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='strobesbufs.messier.workflow.services.GetResultsRequest.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETRESULTSREQUEST_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=663,
)


_GETRESULTSRESPONSE = _descriptor.Descriptor(
  name='GetResultsResponse',
  full_name='strobesbufs.messier.workflow.services.GetResultsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='strobesbufs.messier.workflow.services.GetResultsResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=727,
)

_WORKFLOWVALIDATERESPONSE.fields_by_name['errors'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_WORKFLOWVALIDATERESPONSE.fields_by_name['workflow'].message_type = strobesbufs_dot_messier_dot_workflows_dot_workflow__pb2._WORKFLOW
_WORKFLOWEXECUTEREQUEST.fields_by_name['workflow'].message_type = strobesbufs_dot_messier_dot_workflows_dot_workflow__pb2._WORKFLOW
_WORKFLOWEXECUTERESPONSE.fields_by_name['errors'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_GETRESULTSREQUEST.fields_by_name['type'].enum_type = _GETRESULTSREQUEST_TYPE
_GETRESULTSREQUEST_TYPE.containing_type = _GETRESULTSREQUEST
_GETRESULTSRESPONSE.fields_by_name['results'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['WorkflowValidateRequest'] = _WORKFLOWVALIDATEREQUEST
DESCRIPTOR.message_types_by_name['WorkflowValidateResponse'] = _WORKFLOWVALIDATERESPONSE
DESCRIPTOR.message_types_by_name['WorkflowExecuteRequest'] = _WORKFLOWEXECUTEREQUEST
DESCRIPTOR.message_types_by_name['WorkflowExecuteResponse'] = _WORKFLOWEXECUTERESPONSE
DESCRIPTOR.message_types_by_name['GetResultsRequest'] = _GETRESULTSREQUEST
DESCRIPTOR.message_types_by_name['GetResultsResponse'] = _GETRESULTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WorkflowValidateRequest = _reflection.GeneratedProtocolMessageType('WorkflowValidateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWVALIDATEREQUEST,
  '__module__' : 'strobesbufs.messier.workflows.services_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.workflow.services.WorkflowValidateRequest)
  })
_sym_db.RegisterMessage(WorkflowValidateRequest)

WorkflowValidateResponse = _reflection.GeneratedProtocolMessageType('WorkflowValidateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWVALIDATERESPONSE,
  '__module__' : 'strobesbufs.messier.workflows.services_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.workflow.services.WorkflowValidateResponse)
  })
_sym_db.RegisterMessage(WorkflowValidateResponse)

WorkflowExecuteRequest = _reflection.GeneratedProtocolMessageType('WorkflowExecuteRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWEXECUTEREQUEST,
  '__module__' : 'strobesbufs.messier.workflows.services_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.workflow.services.WorkflowExecuteRequest)
  })
_sym_db.RegisterMessage(WorkflowExecuteRequest)

WorkflowExecuteResponse = _reflection.GeneratedProtocolMessageType('WorkflowExecuteResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWEXECUTERESPONSE,
  '__module__' : 'strobesbufs.messier.workflows.services_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.workflow.services.WorkflowExecuteResponse)
  })
_sym_db.RegisterMessage(WorkflowExecuteResponse)

GetResultsRequest = _reflection.GeneratedProtocolMessageType('GetResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSREQUEST,
  '__module__' : 'strobesbufs.messier.workflows.services_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.workflow.services.GetResultsRequest)
  })
_sym_db.RegisterMessage(GetResultsRequest)

GetResultsResponse = _reflection.GeneratedProtocolMessageType('GetResultsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSRESPONSE,
  '__module__' : 'strobesbufs.messier.workflows.services_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.workflow.services.GetResultsResponse)
  })
_sym_db.RegisterMessage(GetResultsResponse)



_WORKFLOWSERVICE = _descriptor.ServiceDescriptor(
  name='WorkflowService',
  full_name='strobesbufs.messier.workflow.services.WorkflowService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=730,
  serialized_end=1182,
  methods=[
  _descriptor.MethodDescriptor(
    name='WorkflowValidate',
    full_name='strobesbufs.messier.workflow.services.WorkflowService.WorkflowValidate',
    index=0,
    containing_service=None,
    input_type=_WORKFLOWVALIDATEREQUEST,
    output_type=_WORKFLOWVALIDATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WorkflowExecute',
    full_name='strobesbufs.messier.workflow.services.WorkflowService.WorkflowExecute',
    index=1,
    containing_service=None,
    input_type=_WORKFLOWEXECUTEREQUEST,
    output_type=_WORKFLOWEXECUTERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetResults',
    full_name='strobesbufs.messier.workflow.services.WorkflowService.GetResults',
    index=2,
    containing_service=None,
    input_type=_GETRESULTSREQUEST,
    output_type=_GETRESULTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORKFLOWSERVICE)

DESCRIPTOR.services_by_name['WorkflowService'] = _WORKFLOWSERVICE

# @@protoc_insertion_point(module_scope)
