# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/canis/canis.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/canis/canis.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dstrobesbufs/canis/canis.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x82\x01\n\x05Input\x12)\n\x08new_bugs\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08old_bugs\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08\x66\x65\x61tures\x18\x03 \x01(\t\x12\x11\n\tthreshold\x18\x04 \x01(\x02\"3\n\x07Results\x12(\n\x07results\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\'\n\x05\x43\x61nis\x12\x1e\n\x08RunCanis\x12\x06.Input\x1a\x08.Results\"\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_INPUT = _descriptor.Descriptor(
  name='Input',
  full_name='Input',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_bugs', full_name='Input.new_bugs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_bugs', full_name='Input.old_bugs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='Input.features', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='Input.threshold', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=194,
)


_RESULTS = _descriptor.Descriptor(
  name='Results',
  full_name='Results',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='Results.results', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=247,
)

_INPUT.fields_by_name['new_bugs'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_INPUT.fields_by_name['old_bugs'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_RESULTS.fields_by_name['results'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['Input'] = _INPUT
DESCRIPTOR.message_types_by_name['Results'] = _RESULTS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Input = _reflection.GeneratedProtocolMessageType('Input', (_message.Message,), {
  'DESCRIPTOR' : _INPUT,
  '__module__' : 'strobesbufs.canis.canis_pb2'
  # @@protoc_insertion_point(class_scope:Input)
  })
_sym_db.RegisterMessage(Input)

Results = _reflection.GeneratedProtocolMessageType('Results', (_message.Message,), {
  'DESCRIPTOR' : _RESULTS,
  '__module__' : 'strobesbufs.canis.canis_pb2'
  # @@protoc_insertion_point(class_scope:Results)
  })
_sym_db.RegisterMessage(Results)



_CANIS = _descriptor.ServiceDescriptor(
  name='Canis',
  full_name='Canis',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=249,
  serialized_end=288,
  methods=[
  _descriptor.MethodDescriptor(
    name='RunCanis',
    full_name='Canis.RunCanis',
    index=0,
    containing_service=None,
    input_type=_INPUT,
    output_type=_RESULTS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CANIS)

DESCRIPTOR.services_by_name['Canis'] = _CANIS

# @@protoc_insertion_point(module_scope)
