# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: php_security.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='php_security.proto',
  package='strobesbufs.scrappers.php_security',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12php_security.proto\x12\"strobesbufs.scrappers.php_security\"I\n\x06\x42ranch\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0epublished_date\x18\x02 \x01(\t\x12\x19\n\x11\x61\x66\x66\x65\x63ted_versions\x18\x03 \x03(\t\"\x8b\x01\n\x0bPhpSecurity\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03\x63ve\x18\x03 \x01(\t\x12\x12\n\nreferences\x18\x04 \x03(\t\x12<\n\x08\x62ranches\x18\x05 \x03(\x0b\x32*.strobesbufs.scrappers.php_security.Branch\"O\n\x06Result\x12\x45\n\x0cphp_security\x18\x01 \x03(\x0b\x32/.strobesbufs.scrappers.php_security.PhpSecurityb\x06proto3'
)




_BRANCH = _descriptor.Descriptor(
  name='Branch',
  full_name='strobesbufs.scrappers.php_security.Branch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='strobesbufs.scrappers.php_security.Branch.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published_date', full_name='strobesbufs.scrappers.php_security.Branch.published_date', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affected_versions', full_name='strobesbufs.scrappers.php_security.Branch.affected_versions', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=131,
)


_PHPSECURITY = _descriptor.Descriptor(
  name='PhpSecurity',
  full_name='strobesbufs.scrappers.php_security.PhpSecurity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='strobesbufs.scrappers.php_security.PhpSecurity.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='strobesbufs.scrappers.php_security.PhpSecurity.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cve', full_name='strobesbufs.scrappers.php_security.PhpSecurity.cve', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='references', full_name='strobesbufs.scrappers.php_security.PhpSecurity.references', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branches', full_name='strobesbufs.scrappers.php_security.PhpSecurity.branches', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=273,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='strobesbufs.scrappers.php_security.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='php_security', full_name='strobesbufs.scrappers.php_security.Result.php_security', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=354,
)

_PHPSECURITY.fields_by_name['branches'].message_type = _BRANCH
_RESULT.fields_by_name['php_security'].message_type = _PHPSECURITY
DESCRIPTOR.message_types_by_name['Branch'] = _BRANCH
DESCRIPTOR.message_types_by_name['PhpSecurity'] = _PHPSECURITY
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Branch = _reflection.GeneratedProtocolMessageType('Branch', (_message.Message,), {
  'DESCRIPTOR' : _BRANCH,
  '__module__' : 'php_security_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.php_security.Branch)
  })
_sym_db.RegisterMessage(Branch)

PhpSecurity = _reflection.GeneratedProtocolMessageType('PhpSecurity', (_message.Message,), {
  'DESCRIPTOR' : _PHPSECURITY,
  '__module__' : 'php_security_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.php_security.PhpSecurity)
  })
_sym_db.RegisterMessage(PhpSecurity)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'php_security_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.php_security.Result)
  })
_sym_db.RegisterMessage(Result)


# @@protoc_insertion_point(module_scope)
