# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: debian.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='debian.proto',
  package='strobesbufs.scrappers.debian',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0c\x64\x65\x62ian.proto\x12\x1cstrobesbufs.scrappers.debian\x1a\x1cgoogle/protobuf/struct.proto\"J\n\x08Releases\x12-\n\x0crepositories\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07urgency\x18\x02 \x01(\t\"\x83\x01\n\x06\x44\x65\x62ian\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05scope\x18\x03 \x01(\t\x12\x0b\n\x03\x63ve\x18\x04 \x01(\t\x12\x38\n\x08releases\x18\x05 \x03(\x0b\x32&.strobesbufs.scrappers.debian.Releases\">\n\x06Result\x12\x34\n\x06\x64\x65\x62ian\x18\x01 \x03(\x0b\x32$.strobesbufs.scrappers.debian.Debianb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_RELEASES = _descriptor.Descriptor(
  name='Releases',
  full_name='strobesbufs.scrappers.debian.Releases',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repositories', full_name='strobesbufs.scrappers.debian.Releases.repositories', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='urgency', full_name='strobesbufs.scrappers.debian.Releases.urgency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=150,
)


_DEBIAN = _descriptor.Descriptor(
  name='Debian',
  full_name='strobesbufs.scrappers.debian.Debian',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='strobesbufs.scrappers.debian.Debian.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='strobesbufs.scrappers.debian.Debian.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='strobesbufs.scrappers.debian.Debian.scope', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cve', full_name='strobesbufs.scrappers.debian.Debian.cve', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='releases', full_name='strobesbufs.scrappers.debian.Debian.releases', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=284,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='strobesbufs.scrappers.debian.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='debian', full_name='strobesbufs.scrappers.debian.Result.debian', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=348,
)

_RELEASES.fields_by_name['repositories'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_DEBIAN.fields_by_name['releases'].message_type = _RELEASES
_RESULT.fields_by_name['debian'].message_type = _DEBIAN
DESCRIPTOR.message_types_by_name['Releases'] = _RELEASES
DESCRIPTOR.message_types_by_name['Debian'] = _DEBIAN
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Releases = _reflection.GeneratedProtocolMessageType('Releases', (_message.Message,), {
  'DESCRIPTOR' : _RELEASES,
  '__module__' : 'debian_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.debian.Releases)
  })
_sym_db.RegisterMessage(Releases)

Debian = _reflection.GeneratedProtocolMessageType('Debian', (_message.Message,), {
  'DESCRIPTOR' : _DEBIAN,
  '__module__' : 'debian_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.debian.Debian)
  })
_sym_db.RegisterMessage(Debian)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'debian_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.debian.Result)
  })
_sym_db.RegisterMessage(Result)


# @@protoc_insertion_point(module_scope)
