# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: packet_storm.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='packet_storm.proto',
  package='strobesbufs.scrappers.packet_storm',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12packet_storm.proto\x12\"strobesbufs.scrappers.packet_storm\"I\n\x07\x45xploit\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\"i\n\x0bPacketStorm\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0b\n\x03\x63ve\x18\x02 \x01(\t\x12=\n\x08\x65xploits\x18\x03 \x03(\x0b\x32+.strobesbufs.scrappers.packet_storm.Exploit\"O\n\x06Result\x12\x45\n\x0cpacket_storm\x18\x01 \x03(\x0b\x32/.strobesbufs.scrappers.packet_storm.PacketStormb\x06proto3'
)




_EXPLOIT = _descriptor.Descriptor(
  name='Exploit',
  full_name='strobesbufs.scrappers.packet_storm.Exploit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='strobesbufs.scrappers.packet_storm.Exploit.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='strobesbufs.scrappers.packet_storm.Exploit.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link', full_name='strobesbufs.scrappers.packet_storm.Exploit.link', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='strobesbufs.scrappers.packet_storm.Exploit.tags', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=131,
)


_PACKETSTORM = _descriptor.Descriptor(
  name='PacketStorm',
  full_name='strobesbufs.scrappers.packet_storm.PacketStorm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='strobesbufs.scrappers.packet_storm.PacketStorm.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cve', full_name='strobesbufs.scrappers.packet_storm.PacketStorm.cve', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exploits', full_name='strobesbufs.scrappers.packet_storm.PacketStorm.exploits', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=238,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='strobesbufs.scrappers.packet_storm.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='packet_storm', full_name='strobesbufs.scrappers.packet_storm.Result.packet_storm', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=319,
)

_PACKETSTORM.fields_by_name['exploits'].message_type = _EXPLOIT
_RESULT.fields_by_name['packet_storm'].message_type = _PACKETSTORM
DESCRIPTOR.message_types_by_name['Exploit'] = _EXPLOIT
DESCRIPTOR.message_types_by_name['PacketStorm'] = _PACKETSTORM
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Exploit = _reflection.GeneratedProtocolMessageType('Exploit', (_message.Message,), {
  'DESCRIPTOR' : _EXPLOIT,
  '__module__' : 'packet_storm_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.packet_storm.Exploit)
  })
_sym_db.RegisterMessage(Exploit)

PacketStorm = _reflection.GeneratedProtocolMessageType('PacketStorm', (_message.Message,), {
  'DESCRIPTOR' : _PACKETSTORM,
  '__module__' : 'packet_storm_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.packet_storm.PacketStorm)
  })
_sym_db.RegisterMessage(PacketStorm)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'packet_storm_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.packet_storm.Result)
  })
_sym_db.RegisterMessage(Result)


# @@protoc_insertion_point(module_scope)
