# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strobesbufs.messier.workflows import services_pb2 as strobesbufs_dot_messier_dot_workflows_dot_services__pb2


class WorkflowServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.WorkflowValidate = channel.unary_unary(
                '/strobesbufs.messier.workflow.services.WorkflowService/WorkflowValidate',
                request_serializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowValidateRequest.SerializeToString,
                response_deserializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowValidateResponse.FromString,
                )
        self.WorkflowExecute = channel.unary_unary(
                '/strobesbufs.messier.workflow.services.WorkflowService/WorkflowExecute',
                request_serializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowExecuteRequest.SerializeToString,
                response_deserializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowExecuteResponse.FromString,
                )
        self.GetResults = channel.unary_unary(
                '/strobesbufs.messier.workflow.services.WorkflowService/GetResults',
                request_serializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.GetResultsRequest.SerializeToString,
                response_deserializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.GetResultsResponse.FromString,
                )


class WorkflowServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def WorkflowValidate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WorkflowExecute(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResults(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkflowServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'WorkflowValidate': grpc.unary_unary_rpc_method_handler(
                    servicer.WorkflowValidate,
                    request_deserializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowValidateRequest.FromString,
                    response_serializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowValidateResponse.SerializeToString,
            ),
            'WorkflowExecute': grpc.unary_unary_rpc_method_handler(
                    servicer.WorkflowExecute,
                    request_deserializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowExecuteRequest.FromString,
                    response_serializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowExecuteResponse.SerializeToString,
            ),
            'GetResults': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResults,
                    request_deserializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.GetResultsRequest.FromString,
                    response_serializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.GetResultsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strobesbufs.messier.workflow.services.WorkflowService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WorkflowService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def WorkflowValidate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strobesbufs.messier.workflow.services.WorkflowService/WorkflowValidate',
            strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowValidateRequest.SerializeToString,
            strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowValidateResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WorkflowExecute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strobesbufs.messier.workflow.services.WorkflowService/WorkflowExecute',
            strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowExecuteRequest.SerializeToString,
            strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowExecuteResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strobesbufs.messier.workflow.services.WorkflowService/GetResults',
            strobesbufs_dot_messier_dot_workflows_dot_services__pb2.GetResultsRequest.SerializeToString,
            strobesbufs_dot_messier_dot_workflows_dot_services__pb2.GetResultsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)
