# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/messier/functions/function.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strobesbufs.messier.functions import slack_pb2 as strobesbufs_dot_messier_dot_functions_dot_slack__pb2
from strobesbufs.messier.functions import git_pb2 as strobesbufs_dot_messier_dot_functions_dot_git__pb2
from strobesbufs.messier.functions import svn_pb2 as strobesbufs_dot_messier_dot_functions_dot_svn__pb2
from strobesbufs.messier.functions import docker_pb2 as strobesbufs_dot_messier_dot_functions_dot_docker__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/messier/functions/function.proto',
  package='strobesbufs.messier.function',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,strobesbufs/messier/functions/function.proto\x12\x1cstrobesbufs.messier.function\x1a)strobesbufs/messier/functions/slack.proto\x1a\'strobesbufs/messier/functions/git.proto\x1a\'strobesbufs/messier/functions/svn.proto\x1a*strobesbufs/messier/functions/docker.proto\"\xe8\x01\n\x08\x46unction\x12\x34\n\x05Slack\x18\x01 \x01(\x0b\x32#.strobesbufs.messier.function.SlackH\x00\x12\x30\n\x03Git\x18\x02 \x01(\x0b\x32!.strobesbufs.messier.function.GitH\x00\x12\x30\n\x03Svn\x18\x03 \x01(\x0b\x32!.strobesbufs.messier.function.SvnH\x00\x12\x36\n\x06\x44ocker\x18\x04 \x01(\x0b\x32$.strobesbufs.messier.function.DockerH\x00\x42\n\n\x08\x66unctionb\x06proto3'
  ,
  dependencies=[strobesbufs_dot_messier_dot_functions_dot_slack__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_functions_dot_git__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_functions_dot_svn__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_functions_dot_docker__pb2.DESCRIPTOR,])




_FUNCTION = _descriptor.Descriptor(
  name='Function',
  full_name='strobesbufs.messier.function.Function',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Slack', full_name='strobesbufs.messier.function.Function.Slack', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Git', full_name='strobesbufs.messier.function.Function.Git', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Svn', full_name='strobesbufs.messier.function.Function.Svn', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Docker', full_name='strobesbufs.messier.function.Function.Docker', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='function', full_name='strobesbufs.messier.function.Function.function',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=248,
  serialized_end=480,
)

_FUNCTION.fields_by_name['Slack'].message_type = strobesbufs_dot_messier_dot_functions_dot_slack__pb2._SLACK
_FUNCTION.fields_by_name['Git'].message_type = strobesbufs_dot_messier_dot_functions_dot_git__pb2._GIT
_FUNCTION.fields_by_name['Svn'].message_type = strobesbufs_dot_messier_dot_functions_dot_svn__pb2._SVN
_FUNCTION.fields_by_name['Docker'].message_type = strobesbufs_dot_messier_dot_functions_dot_docker__pb2._DOCKER
_FUNCTION.oneofs_by_name['function'].fields.append(
  _FUNCTION.fields_by_name['Slack'])
_FUNCTION.fields_by_name['Slack'].containing_oneof = _FUNCTION.oneofs_by_name['function']
_FUNCTION.oneofs_by_name['function'].fields.append(
  _FUNCTION.fields_by_name['Git'])
_FUNCTION.fields_by_name['Git'].containing_oneof = _FUNCTION.oneofs_by_name['function']
_FUNCTION.oneofs_by_name['function'].fields.append(
  _FUNCTION.fields_by_name['Svn'])
_FUNCTION.fields_by_name['Svn'].containing_oneof = _FUNCTION.oneofs_by_name['function']
_FUNCTION.oneofs_by_name['function'].fields.append(
  _FUNCTION.fields_by_name['Docker'])
_FUNCTION.fields_by_name['Docker'].containing_oneof = _FUNCTION.oneofs_by_name['function']
DESCRIPTOR.message_types_by_name['Function'] = _FUNCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Function = _reflection.GeneratedProtocolMessageType('Function', (_message.Message,), {
  'DESCRIPTOR' : _FUNCTION,
  '__module__' : 'strobesbufs.messier.functions.function_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.function.Function)
  })
_sym_db.RegisterMessage(Function)


# @@protoc_insertion_point(module_scope)
